@@ -30,5 +30,5 @@ class DKConnection():
         try:
             testStr = order['servings'][0]['testresults']
         except KeyError:
-            print "Error: No tests in OrderRun Object"
+            print("Error: No tests in OrderRun Object")
         return dk_api_helpers.parseTestString(testStr)
